==> sal-cluster-admin-api-1.9.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/RemoveShardReplicaInput.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import java.lang.String;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.RpcInput;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>cluster-admin</b>
 * <pre>
 * input {
 *   leaf shard-name {
 *     type string;
 *   }
 *   leaf member-name {
 *     type string;
 *   }
 *   leaf data-store-type {
 *     type data-store-type;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>cluster-admin/remove-shard-replica/input</i>
 *
 * <p>To create instances of this class use {@link RemoveShardReplicaInputBuilder}.
 * @see RemoveShardReplicaInputBuilder
 *
 */
public interface RemoveShardReplicaInput
    extends
    RpcInput,
    Augmentable<RemoveShardReplicaInput>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("input");

    /**
     * The name of the shard for which to remove the replica.
     *
     *
     *
     * @return <code>java.lang.String</code> <code>shardName</code>, or <code>null</code> if not present
     */
    @Nullable String getShardName();
    
    /**
     * The cluster member from which the shard replica should be removed
     *
     *
     *
     * @return <code>java.lang.String</code> <code>memberName</code>, or <code>null</code> if not present
     */
    @Nullable String getMemberName();
    
    /**
     * The type of the data store to which the replica belongs
     *
     *
     *
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.DataStoreType</code> <code>dataStoreType</code>, or <code>null</code> if not present
     */
    @Nullable DataStoreType getDataStoreType();

}

==> sal-cluster-admin-api-1.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/RemoveShardReplicaInput.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import java.lang.Class;
import java.lang.Override;
import java.lang.String;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.RpcInput;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>cluster-admin</b>
 * <pre>
 * input {
 *   leaf shard-name {
 *     type string;
 *   }
 *   leaf member-name {
 *     type string;
 *   }
 *   leaf data-store-type {
 *     type data-store-type;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>cluster-admin/remove-shard-replica/input</i>
 *
 * <p>To create instances of this class use {@link RemoveShardReplicaInputBuilder}.
 * @see RemoveShardReplicaInputBuilder
 *
 */
public interface RemoveShardReplicaInput
    extends
    RpcInput,
    Augmentable<RemoveShardReplicaInput>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("input");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.RemoveShardReplicaInput> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.RemoveShardReplicaInput.class;
    }
    
    /**
     * The name of the shard for which to remove the replica.
     *
     *
     *
     * @return <code>java.lang.String</code> <code>shardName</code>, or <code>null</code> if not present
     */
    @Nullable String getShardName();
    
    /**
     * The cluster member from which the shard replica should be removed
     *
     *
     *
     * @return <code>java.lang.String</code> <code>memberName</code>, or <code>null</code> if not present
     */
    @Nullable String getMemberName();
    
    /**
     * The type of the data store to which the replica belongs
     *
     *
     *
     * @return <code>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013.DataStoreType</code> <code>dataStoreType</code>, or <code>null</code> if not present
     */
    @Nullable DataStoreType getDataStoreType();

}
